@@ -10,10 +10,10 @@ package URI::db;
 # db:engine://[user[:password]@][netloc][:port][/dbname][?param1=value1&...]
 
 use strict;
-use 5.8.1;
+use 5.008001;
 use base 'URI::Nested';
 use URI::_db;
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 sub prefix       { 'db' }
 sub nested_class { 'URI::_db' }
